import httpx as h
import random
import json
import os

from .template import ImageGet, ImageGetException

class ImageGetImmich(ImageGet):

    def __init__(self) -> None:
        api_root_url = os.getenv("IMMICH_API_URL")
        api_key = os.getenv("IMMICH_API_KEY")

        headers = {
            "x-api-key": api_key
        }

        super().__init__(
            base_url=api_root_url,
            headers=headers
            )


    def get_random_image_ids(self, num=1) -> str:
        album_id = os.getenv("IMMICH_ALBUM_ID")
        url = self.base_url + "albums/" + album_id
        headers = self.headers | {"Accept": "application/json"}
        
        response = h.request("GET", url, headers=headers, data={})
        # raises an htppx exception if anything goes wrong
        if response.status_code == 200:
            response = json.loads(response.text)
        else:
            raise ImageGetException(f"Error in step get_random_image_id: {response.status_code}")

        images = response['assets']

        print(f"Picking {num} random id(s) out of {len(images)} album images")
        ids = []
        for i in range(num):
            image = random.choice(images)
            print(f"Image considered: {image['exifInfo']}")
            ids.append(image["id"])

        return ids


    def get_image_file(self, image_id: str) -> bytearray:
        url = self.base_url + f"assets/{image_id}/original"
        print(url)

        headers = self.headers | {"Accept": "application/octet-stream"}
        response = h.request("GET", url, headers=headers, data={})
        if not response.status_code == 200:
            raise ImageGetException(f"Error in step get_image_file: {response.status_code}" )
            
        return response.content
