import sys
from pathlib import Path
import os

from image_convert import ImageShrink
from get.combined import ImageGetCombined
from get.template import ImageGetException
from image_show import ImageShow
import notify

VARS = Path("../deploy/program_variables.yml")

if os.getenv("IMMICH_API_URL") is None:
    # values are not set, import them from local yaml file
    import yaml
    with open(VARS, "r") as f:
        config = yaml.safe_load(f)
        for key, value in config.items():
            os.environ[key] = value

if len(sys.argv) == 2 and sys.argv[1] == "test":
    print("Running test")
    shower = ImageShow()
    shower.draw_sample_image()
    sys.exit()

shrink_kwargs = {}
if "reduce" in sys.argv:
    print("Enabling color reduction")
    shrink_kwargs["reduce_colors"] = True


try:
    getter = ImageGetCombined()
    converter = ImageShrink(**shrink_kwargs)
    shower = ImageShow()
except Exception as e:
    print("Failed to initialize")
    notify.notify_status("Failed to initialize")
    raise e

try:
    image = getter.get_random_image()
    image = converter.convert(image)
    shower.show_image(image)
    notify.notify_status("Success")
except ImageGetException as e:
    print("Failed to get image")
    notify.notify_status(f"Failed to get image: {e}")
    raise e